@@ -17,8 +17,7 @@
 
 #include "sources.ih"
 
-void Sources::destroy()
-{
+void Sources::destroy() {
     OpenMP::ScopedLock instantiateLock(s_instanceLock);
     if(s_instance) {
         delete s_instance;
