@@ -1,5 +1,6 @@
 /*
   This file is part of ccbuild.
+  Copyright (C) 2013  A. Bram Neijt <bneijt@gmail.com>
 
   ccbuild is free software: you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -15,9 +16,6 @@
   along with ccbuild.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-
-
-
 #include "string.hh"
 #include <string>
 #include <vector>
@@ -29,19 +27,16 @@
 using namespace std;
 using namespace bneijt;
 int main(int argc, char **argv)
-try
-{
-  String s("a hello b");
+try {
+    String s("a hello b");
 #define REP(a,b) std::cout << "Replace '" << a << "' with '" << b << "': " << s.replace(a,b) << "\n"
-  REP("a","b");
-  REP("a", "hello");
-  REP("hello", "billy");
-  cout << "\n";
-  return 0;
-}
-catch(const std::exception &e)
-{
-	//All is LOST... nothing to do here but die
-  cerr << "Caught std::exception (" << typeid(e).name() << "): " << e.what();
-  cerr << "\nPlease report this as a bug.\n";
+    REP("a","b");
+    REP("a", "hello");
+    REP("hello", "billy");
+    cout << "\n";
+    return 0;
+} catch(const std::exception &e) {
+    //All is LOST... nothing to do here but die
+    cerr << "Caught std::exception (" << typeid(e).name() << "): " << e.what();
+    cerr << "\nPlease report this as a bug.\n";
 }
